Float64Array class

Inheritance

Constructors

Float64Array(int size)
Float64Array.from(List<double> listData)
Float64Array.fromList(List<double> listData)

Properties

byteLength → int
no setterinherited
BYTES_PER_ELEMENT → int
no setterinherited
data → Pointer<Double>
no setterinherited
disposed ↔ bool
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
len → int
no setterinherited
length → int
no setterinherited
lengthInBytes → int
no setterinherited
oneByteSize ↔ int
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clone() → Float64Array
override
copy(NativeArray<num> source) → void
inherited
dispose() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(List<double> newList, [int index = 0]) → NativeArray<num>
inherited
setArray(Float64Array newList, [int index = 0]) → NativeFloat64Array
inherited
sublist(int start, [int? end]) → List<double>
inherited
toDartList() → Float64List
inherited
toJson() → List<double>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](int index) → double
inherited
operator []=(int index, double value) → void
inherited