Int16Array class

Inheritance

Constructors

Int16Array(int size)
Int16Array.from(List<int> listData)
Int16Array.fromList(List<int> listData)

Properties

byteLength → int
no setterinherited
BYTES_PER_ELEMENT → int
no setterinherited
data → Pointer<Int16>
no setterinherited
disposed ↔ bool
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
len → int
no setterinherited
length → int
no setterinherited
lengthInBytes → int
no setterinherited
oneByteSize ↔ int
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clone() → Int16Array
override
copy(NativeArray<num> source) → void
inherited
dispose() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(List<int> newList, [int index = 0]) → NativeArray<num>
inherited
sublist(int start, [int? end]) → List<int>
inherited
toDartList() → Int16List
inherited
toJson() → List<int>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](int index) → int
inherited
operator []=(int index, int value) → void
inherited