NativeArray<T extends num> class abstract

Implementers

Constructors

NativeArray(int size)

Properties

byteLength → int
no setter
BYTES_PER_ELEMENT → int
no setter
data → dynamic
no setter
disposed ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
len → int
no setter
length → int
no setter
lengthInBytes → int
no setter
oneByteSize ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clone() → NativeArray<num>
copy(NativeArray<num> source) → void
dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(List<T> newList, [int index = 0]) → NativeArray<num>
sublist(int start, [int? end]) → List<T>
toDartList() → List<T>
toJson() → List<T>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](int index) → T
operator []=(int index, T value) → void