OpenGLES class

Inheritance

Constructors

OpenGLES(Map<String, dynamic> options)

Properties

defaultFrameBuffer → int
no setteroverride
defaultTexture → int
no setteroverride
egl → LibEGL
no setter
element ↔ dynamic
getter/setter pairinherited
frameBuffer ↔ Pointer<Uint32>
getter/setter pair
frameBufferTexture ↔ Pointer<Uint32>
getter/setter pair
gl → dynamic
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
renderBuffer ↔ Pointer<Uint32>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
override
eglMakeCurrent(int display, int draw, int read, int context) → dynamic
getEglLibrary() → DynamicLibrary?
getGLLibrary() → DynamicLibrary?
glFlush() → void
inherited
initOpenGL(int width, int height, bool bool, List<int> egls) → void
inherited
makeCurrent(List<int> egls) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited