OpenGLWeb class

Inheritance

Constructors

OpenGLWeb(Map<String, dynamic> options)

Properties

defaultFrameBuffer → int
no setterinherited
defaultTexture → int
no setterinherited
divId ↔ String
getter/setter pair
dpr ↔ num
getter/setter pair
element ↔ dynamic
getter/setter pairinherited
gl → dynamic
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
height ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width ↔ int
getter/setter pair

Methods

dispose() → void
inherited
glFlush() → void
inherited
initOpenGL(int width, int height, bool bool, List<int> egls) → void
inherited
makeCurrent(List<int> egls) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited